=begin

Permission to use, copy, modify, and distribute this software for any purpose
and without fee is hereby granted, provided this notice appears in any copies.

THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED 
WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF 
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

Author:  kyyu (7-25-2011) v1.2

Description:  This plugin makes it easier to use the scale tool, on thin sheet parts.  
When the scale tool is used on a modified component/group, the drag handles are reduces 
from the normal 26 to only 10.  Tested on SU8, and also seems to work with SU7.

Activated from (Plugins menu "[ky] Simple Scale Handles") or (Toolbar).
If nothing is selected, than all active groups/components are processed.
Toolbar icons are depressed, as a visual indicator when all comp/groups are proccessed.
Depressed icons can still be clicked, for example to process a selection.
There is an option below, for the toolbar to ignore selection.

Options:  There are 3 vaiables at the beginning of the script, whos value can be changed to customize the plugin.  
	[menu = true]		-load "Plugins Menu item"
	[toolbar = true]		-load Toolbar
	[@toolbar_all = false]		-if true, Toolbar will ignore selection, and only process all active comp/groups.

Tip: You need to have the z axis, of group/component, aligned with the thickness of the sheet.


History:   v1.0	(7-21-2011) initial version
           v1.1	(7-23-2011) added Toolbar
					 v1.2 (7-25-2011) Toolbar now processes selection, with option to only process all.
=end

module KY_simple_scale_handles
menu = true		# Set to false, if you don't want menu item in "Plugins Menu"
toolbar = true		# Set to false, if you don't want a toolbar
@toolbar_all = false		# Set to true, if you want toolbar to ignore selection, and only process all active comp/groups.

	
	def self.main(result)
		model = Sketchup.active_model
		ent = model.active_entities
		sel = model.selection
			if (result=='menu') or !(@toolbar_all)
				if !sel[0] then (stuff=ent.to_a; all=true) else stuff=sel.to_a end
			else (stuff=ent.to_a; all=true) end		
		defin = []		
		stuff.each do |e|
			if e.is_a?(Sketchup::Group) then defin<<e.entities.parent
			elsif e.is_a?(Sketchup::ComponentInstance) then defin<<e.definition end
		end # each	
		defin.uniq!;   puts defin.length
		if result=='menu' then (result = open_inputbox) end
		return if !result		
		defin.each {|e| if result=='Simple' then e.behavior.no_scale_mask=88 else e.behavior.no_scale_mask=0 end}
		if all then model.set_attribute('ky_misc', 'simple_scale_handles', result) end
	end # def
	
	def self.open_inputbox		
		prompts = ['Modify Component '] 
		defaults = ['Simple'] 
		list = ["Simple|Default"] 
		result = UI.inputbox(prompts, defaults, list, "Hide Scale Tool Handles")
		return if !result
		return result[0]
	end # def
	
	def self.simple_handles_validation_proc(result)
		model = Sketchup.active_model
		case result
			when 'Simple'
				if model.get_attribute('ky_misc', 'simple_scale_handles') == 'Simple'
					return MF_CHECKED
				else
					return MF_UNCHECKED
				end
			when 'Default'
				if model.get_attribute('ky_misc', 'simple_scale_handles') == 'Default'
					return MF_CHECKED
				else
					return MF_UNCHECKED
				end
		end		
	end # def
	

	if not(file_loaded?(__FILE__))
		if menu then UI.menu("Plugins").add_item("[ky] Simple Scale Handles") { main( 'menu' ) }	end
		if toolbar
			tb = UI::Toolbar.new('Simple Scale Handles')
		#########	
			cmd = UI::Command.new('Simple') { main( 'Simple' ) }
			cmd.small_icon = cmd.large_icon = File.join(File.dirname(__FILE__),'ky_simple scale handles/s.gif')
			cmd.tooltip = cmd.status_bar_text = 'Simple Scale Tool Handles'
			cmd.set_validation_proc { simple_handles_validation_proc('Simple') }
			tb.add_item(cmd)
		##########	
			cmd = UI::Command.new('Default') { main( 'Default' ) }
			cmd.small_icon = cmd.large_icon = File.join(File.dirname(__FILE__),'ky_simple scale handles/d.gif')
			cmd.tooltip = cmd.status_bar_text = 'Default Scale Tool Handles'
			cmd.set_validation_proc { simple_handles_validation_proc('Default') }
			tb.add_item(cmd)
		##########		
			state = tb.get_last_state 
			if(state == TB_NEVER_SHOWN)
				tb.show 
			elsif (state == TB_VISIBLE)
				tb.restore
			end
		end # if toolbar			
	end # if not file loaded
	file_loaded(__FILE__)
	
end # module